PAI Python SDK 文档
===========================================

**PAI (Platform for Artificial Intelligence)** 是阿里云提供的机器学习平台，
支持用户在云上完成从数据处理、训练、模型管理、到模型部署的端到端的机器学习流程。

**PAI Python SDK** 是PAI提供的Python SDK，提供了更易用的API，
支持算法工程师简单地使用Python在PAI完成模型训练和部署，串联机器学习的流程。


概览
--------


.. toctree::
    :maxdepth: 1
    :caption: 快速开始

    quick-tour/installation
    quick-tour/example


.. toctree::
    :maxdepth: 1
    :caption: 用户手册

    user-guide/train
    user-guide/inference
    user-guide/pretrained-model
    user-guide/processing-job


.. toctree::
    :maxdepth: 1
    :caption: 示例教程

    tutorial/framework
    tutorial/train
    tutorial/predict
    tutorial/advance


.. toctree::
    :maxdepth: 1
    :caption: Reference

    reference
    PAI帮助文档 <https://help.aliyun.com/product/30347.html>
